@@ -28,7 +28,7 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 
-#include <libtracker-common/tracker-common.h>
+#include <libtracker-miners-common/tracker-common.h>
 
 #include <libtracker-miner/tracker-miner.h>
 
